@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Patch.py 12973 2021-06-13 11:56:03Z Becca $
+# $Id: Patch.py 12978 2021-06-16 09:15:13Z Becca $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Becca $ (last)
-# $Date: 2021-06-13 19:56:03 +0800 (Sun, 13 Jun 2021) $
-# $Revision: 12973 $
+# $Date: 2021-06-16 17:15:13 +0800 (週三, 16 六月 2021) $
+# $Revision: 12978 $
 #
 # Contributors:
 #  Bear
@@ -51,6 +51,34 @@ def attachDebugSettings(settingsDict):
     else:
         extendInstalledApps(settingsDict, ('django_extensions',))
 
+    # debug toolbar
+    try:
+        import debug_toolbar
+    except ImportError:
+        warnings.warn(
+            colored(
+                "Can't import debug_toolbar."
+                " Please install django-debug-toolbar==3.2.1.",
+                'yellow', attrs=['bold']
+            )
+        )
+    else:
+        if settingsDict.get('DEBUG_TOOLBAR_ENABLE', None):
+            extendInstalledApps(settingsDict, ('debug_toolbar',))
+            extendMiddlewareClasses(
+                settingsDict,
+                ("debug_toolbar.middleware.DebugToolbarMiddleware",)
+            )
+
+            toolbarSettings = {
+                'INTERNAL_IPS': ['127.0.0.1'],
+            }
+            update(settingsDict, toolbarSettings)
+
+            populateEnvToSettings((
+                'INTERNAL_IPS',
+            ), settingsDict)
+
 def extendSettings(settingsLocals):
     """
     Extend settings.
